# chibihash
[![CI](https://github.com/jimexist/chibihash/actions/workflows/ci.yaml/badge.svg)](https://github.com/jimexist/chibihash/actions/workflows/ci.yaml)

- [Original implementation](https://github.com/N-R-K/ChibiHash/blob/master/chibihash64.h)
